@@ -84,7 +84,7 @@ BEGIN {
 with 'Log::LogMethods';
 with 'Data::Result::Moo';
 }
-our $VERSION='1.011';
+our $VERSION='1.013';
 
 sub BUILD {
   my ($self)=@_;
@@ -610,7 +610,12 @@ sub que_function {
     $self->results->{$id}=$self->new_true($response);
     
     $self->run_next;
-    return unless $self->in_control_loop;
+    if($self->in_control_loop) {
+      if($self->que_count==0) {
+        $self->loop_control->send if $self->loop_control;
+      }
+      return;
+    }
 
     if($self->{que_count}==0) {
       $self->log_debug('Que Count has reached 0');
@@ -618,7 +623,7 @@ sub que_function {
         $self->log_info("A result outside of it's lifecycle has arived loop_id: $loop_id que_id: $id, but we are in loop_id: ".$self->loop_id);
         return;
       }
-      $self->loop_control->send;
+      $self->loop_control->send if $self->loop_control;
     } else {
       $self->log_debug("Que Count is at $self->{que_count}");
     }
@@ -653,13 +658,13 @@ sub block_loop : BENCHMARK_DEBUG {
       $result=$self->new_false("Timed out before we got a response");
       $self->log_error("Request Que timed out, Que Count is: ".$self->que_count);
       $self->loop_control->send;
-
     });
     $self->run_next;
     $self->loop_control->send if $self->{que_count}<=0;
 
     $self->loop_control->recv;
   }
+  $self->loop_control(undef);
   undef $t;
   $self->in_control_loop(0);
   $self->loop_id($self->loop_id + 1);
